@@ -394,6 +394,19 @@ class PyABaSoS(object):
         self.pmap[new] = tmp
         
     def relate(self, dv, idv, func=None):
+        """
+        Establish functional relations
+        
+        Parameters
+        ----------
+        dv : string
+            Dependent variable
+        idv : string or list of strings
+            Independent variables
+        func : callable
+            Callable taking the independent variables as arguments
+            and returns the value of the dependent variable.
+        """
         if isinstance(idv, six.string_types):
             # Convert single string into list
             idv = [idv]
@@ -413,6 +426,8 @@ class PyABaSoS(object):
             self.pmap[n].affects.update([self.pmap[dv]])
         # Trigger update of the value of the related parameter
         self.pmap[dv].updateRelation()
+        # Freeze the dependent variable
+        self.freeze(dv)
     
     def copy(self):
         """ Return a shallow copy of the object """
@@ -460,7 +475,7 @@ class PyABaSoS(object):
             Complete parameter name
         """
         result = b
-        if not r is None:
+        if (not r is None) and (r != ""):
             result += "_" + r
         if (not n is None) and (n != 0):
             result += ("(%d)" % n)
@@ -1454,6 +1469,8 @@ def sampleEMCEE2(m, pargs=(), walkerdimfac=4, scales=None,
     walkerdimfac : int, optional
         Determines the number of walkers. By default, four times the
         number of free parameters is used.
+    pargs : tuple
+        Content of 'args' argument handed to EnsembleSampler
     scales : dictionary, optional
         The scales argument can be used to control the initial distribution
         of the walkers. By default, all walkers are distributed around the
@@ -1581,7 +1598,7 @@ def sampleEMCEE2(m, pargs=(), walkerdimfac=4, scales=None,
             widgets=widgets, maxval=sampleArgs["iters"]).start()
     
     n = 0
-    for pos, prob, state, blobs in emceeSampler.sample(pos, rstate0=state, iterations=sampleArgs["iters"], thin=1, storechain=True):
+    for pos, prob, state, blobs in emceeSampler.sample(pos, rstate0=state, iterations=sampleArgs["iters"], thin=1):
         n += 1
         if (not sampleArgs["progress"] is None) and (n % sampleArgs["progress"] == 0):
             if ic.check["progressbar"]:
@@ -1589,9 +1606,7 @@ def sampleEMCEE2(m, pargs=(), walkerdimfac=4, scales=None,
             else:
                 print("EMCEE: Reached iteration ",
                       n, " of ", sampleArgs["iters"])
-    
-    print(emceeSampler.blobs)
-    
+
     # Save the chain to a file
     if not dbfile is None:
         
@@ -1677,6 +1692,37 @@ for m in _ml:
     setattr(_fbo2module, m[0], _fuf2ModelFactory(m[1], m[2]) )
 
 
+class Poly2d(MBOEv):
+    """
+    Bivariate (2d) polynomial model
+    
+    Parameters
+    ----------
+    nx, ny : int
+        Number of coefficients in first and second variable
+    """
+
+    def __init__(self, nx, ny):
+        if (nx < 0) or (ny < 0):
+            raise(PE.PyAValError("nx and ny must be non-negative integers."))
+        self.nx, self.ny = nx, ny
+        pars = []
+        for x in range(nx+1):
+            for y in range(ny+1):
+                pars.append("c%d-%d" % (x,y))
+        # 'pars' specifies parameter names in the model
+        MBOEv.__init__(self, pars=pars, rootName="Poly2d")
+
+    def evaluate(self, x, *args):
+        """
+        Evaluate model at points (x[::,0], x[::,1])
+        """
+        c = np.zeros( (self.nx+1, self.ny+1) )
+        for i in range(self.nx+1):
+            for j in range(self.ny+1):
+                c[i,j] = self["c%d-%d" % (i,j)]
+        return np.polynomial.polynomial.polyval2d(x[::,0], x[::,1], c)
+
 # 
 # # class GF1d(MBO2):
 # #     
