@@ -180,15 +180,26 @@ class Gls:
             The error of the data values.
 
         """
+        def checkvalid(x, m):
+            # Check for NaNs
+            if np.any(~np.isfinite(x)):
+                raise(PE.PyAValError(m + " contains invalid values such as NaN or Inf.", \
+                                    where="GLS", \
+                                    solution="Remove from input (e.g., using np.isfinite)"))                    
+        
         if isinstance(lc, (tuple, list)):
             # t, y[, e_y] were given as list or tuple.
             if len(lc) in (2, 3):
                 self.t = np.ravel(lc[0])
                 self.y = np.ravel(lc[1])
+                # Check for NaNs
+                checkvalid(self.t, "Time input")
+                checkvalid(self.y, "Flux input")
                 self.e_y = None
-                if len(lc) == 3 and lc[2] is not None:
+                if (len(lc) == 3) and (lc[2] is not None):
                     # Error has been specified.
                     self.e_y = np.ravel(lc[2])
+                    checkvalid(self.e_y, "Flux error input")
             else:
                 raise(ValueError("lc is a list or tuple with " + str(len(lc)) + " elements. Needs to have 2 or 3 elements." + \
                                    " solution=Use 2 or 3 elements (t, y[, e_y]) or an instance of TimeSeries"))
@@ -204,6 +215,7 @@ class Gls:
         if (len(self.th) != self.N) or ((self.e_y is not None) and (len(self.e_y) != self.N)):
             raise(ValueError("Incompatible dimensions of input data arrays (time and flux [and error]). Current shapes are: " + \
                              ', '.join(str(np.shape(x)) for x in (self.t, self.y, self.e_y))))
+            
 
     def _buildFreq(self):
         """
@@ -220,8 +232,6 @@ class Gls:
         self.f = self.freq
 
         if self.freq is None:
-            if self.fast:
-                raise(ValueError("freq and fast cannot be used together."))
             # Build frequency array if not present.
             if self.fbeg is None:
                 self.fbeg = self.fstep if self.Pend is None else 1 / self.Pend
@@ -234,6 +244,8 @@ class Gls:
 
             self.freq = arange(self.fbeg, self.fend, self.fstep)
         else:
+            if self.fast:
+                raise(ValueError("freq and fast cannot be used together."))
             self.fbeg, self.fend = np.min(self.freq), np.max(self.freq)
 
         self.nf = len(self.freq)
@@ -424,29 +436,62 @@ class Gls:
             print("Failed to calculate best-fit sine curve.")
             raise(e)
 
-    def info(self):
+    def info(self, noprint=False):
         """
         Prints some basic statistical output screen.
+        
+        Parameters
+        ----------
+        noprint : boolean
+            If True, printing is suppressed. Default is False.
+        
+        Returns
+        -------
+        Information : dictionary
+            A dictionary with the printed information.
         """
-        print("Generalized LS - statistical output")
-        print("-----------------------------------")
-        print("Number of input points:      %-6d" % self.N)
-        print("Weighted mean of dataset:   % f"  % self._Y)
-        print("Weighted rms of dataset:    % f"  % sqrt(self._YY))
-        print("Time base:                  % f"  % self.tbase)
-        print("Number of frequency points:  %-6d" % self.nf)
-        print()
-        print("Maximum power p [%s]: % f" % (self.norm, self.power.max()))
-        print("RMS of residuals:     % f" % self.rms)
+        
+        info = {"N":self.N, "weighted_mean":self._Y, "weighted_rms":sqrt(self._YY), \
+                "time_base":self.tbase, "no_of_freq_points":self.nf, \
+                "norm":self.norm, "maximum_power":self.power.max(), \
+                "rms_of_residuals":self.rms, \
+                "best_sine_frequency":self.hpstat["fbest"], \
+                "best_sine_frequency_err":self.hpstat["f_err"], \
+                "best_sine_period":1./self.hpstat["fbest"], \
+                "best_sine_period_err":self.hpstat["Psin_err"], \
+                "amplitude":self.hpstat["amp"], \
+                "amplitude_err":self.hpstat["amp_err"], \
+                "phase":self.hpstat["ph"], \
+                "phase_err":self.hpstat["ph_err"], \
+                "phase_t0":self.hpstat["T0"], \
+                "phase_t0_err":self.hpstat["T0_err"], \
+                "offset":self.hpstat["offset"], \
+                "offset_err":self.hpstat["offset_err"]
+            }
         if self.e_y is not None:
-            print("  Mean weighted internal error:  %f" % (sqrt(self.N/sum(1./self.e_y**2))))
-        print("Best sine frequency:  % f +/- % f" % (self.hpstat["fbest"], self.hpstat["f_err"]))
-        print("Best sine period:     % f +/- % f" % (1./self.hpstat["fbest"], self.hpstat["Psin_err"]))
-        print("Amplitude:            % f +/- % f" % (self.hpstat["amp"], self.hpstat["amp_err"]))
-        print("Phase (ph):           % f +/- % f" % (self.hpstat["ph"], self.hpstat["ph_err"]))
-        print("Phase (T0):           % f +/- % f" % (self.hpstat["T0"], self.hpstat["T0_err"]))
-        print("Offset:               % f +/- % f" % (self.hpstat["offset"], self.hpstat["offset_err"]))
-        print("-----------------------------------")
+            info["mean_weighted_internal_error"] = sqrt(self.N/sum(1./self.e_y**2)),
+        
+        if not noprint:
+            print("Generalized LS - statistical output")
+            print("-----------------------------------")
+            print("Number of input points:      %-6d" % self.N)
+            print("Weighted mean of dataset:   % f"  % self._Y)
+            print("Weighted rms of dataset:    % f"  % sqrt(self._YY))
+            print("Time base:                  % f"  % self.tbase)
+            print("Number of frequency points:  %-6d" % self.nf)
+            print()
+            print("Maximum power p [%s]: % f" % (self.norm, self.power.max()))
+            print("RMS of residuals:     % f" % self.rms)
+            if self.e_y is not None:
+                print("  Mean weighted internal error:  %f" % (sqrt(self.N/sum(1./self.e_y**2))))
+            print("Best sine frequency:  % f +/- % f" % (self.hpstat["fbest"], self.hpstat["f_err"]))
+            print("Best sine period:     % f +/- % f" % (1./self.hpstat["fbest"], self.hpstat["Psin_err"]))
+            print("Amplitude:            % f +/- % f" % (self.hpstat["amp"], self.hpstat["amp_err"]))
+            print("Phase (ph):           % f +/- % f" % (self.hpstat["ph"], self.hpstat["ph_err"]))
+            print("Phase (T0):           % f +/- % f" % (self.hpstat["T0"], self.hpstat["T0_err"]))
+            print("Offset:               % f +/- % f" % (self.hpstat["offset"], self.hpstat["offset_err"]))
+            print("-----------------------------------")
+        return info
 
     def plot(self, block=False, period=False):
         """
